@@ -24,11 +24,12 @@ sps_repweights <- function(w, B = 1000, tau = 1, dist = NULL) {
     warning(gettext("some replicate weights are negative; try increasing 'tau'"))
   }
   dim(res) <- c(length(w), B)
+  rownames(res) <- names(w)
   structure(res, tau = tau, class = c("sps_brw", class(res)))
 }
 
 #---- Methods for class 'sps_brw' ----
 print.sps_brw <- function(x, ...) {
-  print(structure(as.numeric(x), dim = dim(x)), ...)
+  print(structure(as.numeric(x), dim = dim(x), dimnames = dimnames(x)), ...)
   invisible(x)
 }
\ No newline at end of file
